@@ -79,6 +79,33 @@ class TestIntrospect(BaseTest):
         self.node_info.acquire_lock.assert_called_once_with()
         self.node_info.release_lock.assert_called_once_with()
 
+    def test_loopback_bmc_address(self, client_mock, add_mock, filters_mock):
+        self.node.driver_info['ipmi_address'] = '127.0.0.1'
+        cli = self._prepare(client_mock)
+        add_mock.return_value = self.node_info
+
+        introspect.introspect(self.node.uuid)
+
+        cli.node.get.assert_called_once_with(self.uuid)
+        cli.node.validate.assert_called_once_with(self.uuid)
+
+        add_mock.assert_called_once_with(self.uuid,
+                                         bmc_address=None,
+                                         ironic=cli)
+        self.node_info.ports.assert_called_once_with()
+        self.node_info.add_attribute.assert_called_once_with('mac',
+                                                             self.macs)
+        filters_mock.assert_called_with(cli)
+        cli.node.set_boot_device.assert_called_once_with(self.uuid,
+                                                         'pxe',
+                                                         persistent=False)
+        cli.node.set_power_state.assert_called_once_with(self.uuid,
+                                                         'reboot')
+        self.node_info.set_option.assert_called_once_with(
+            'new_ipmi_credentials', None)
+        self.node_info.acquire_lock.assert_called_once_with()
+        self.node_info.release_lock.assert_called_once_with()
+
     def test_ok_ilo_and_drac(self, client_mock, add_mock, filters_mock):
         cli = self._prepare(client_mock)
         add_mock.return_value = self.node_info
@@ -188,14 +215,14 @@ class TestIntrospect(BaseTest):
     def test_failed_to_get_node(self, client_mock, add_mock, filters_mock):
         cli = client_mock.return_value
         cli.node.get.side_effect = exceptions.NotFound()
-        self.assertRaisesRegexp(utils.Error,
-                                'Node %s was not found' % self.uuid,
-                                introspect.introspect, self.uuid)
+        self.assertRaisesRegex(utils.Error,
+                               'Node %s was not found' % self.uuid,
+                               introspect.introspect, self.uuid)
 
         cli.node.get.side_effect = exceptions.BadRequest()
-        self.assertRaisesRegexp(utils.Error,
-                                '%s: Bad Request' % self.uuid,
-                                introspect.introspect, self.uuid)
+        self.assertRaisesRegex(utils.Error,
+                               '%s: Bad Request' % self.uuid,
+                               introspect.introspect, self.uuid)
 
         self.assertEqual(0, self.node_info.ports.call_count)
         self.assertEqual(0, filters_mock.call_count)
@@ -210,7 +237,7 @@ class TestIntrospect(BaseTest):
         cli.node.validate.return_value = mock.Mock(power={'result': False,
                                                           'reason': 'oops'})
 
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             utils.Error,
             'Failed validation of power interface',
             introspect.introspect, self.uuid)
@@ -227,7 +254,7 @@ class TestIntrospect(BaseTest):
         cli = client_mock.return_value
         cli.node.get.return_value = self.node
 
-        self.assertRaisesRegexp(
+        self.assertRaisesRegex(
             utils.Error, 'Invalid provision state for introspection: "active"',
             introspect.introspect, self.uuid)
 
@@ -365,9 +392,9 @@ class TestSetIpmiCredentials(BaseTest):
                           'processing')
         self._prepare(client_mock)
 
-        self.assertRaisesRegexp(utils.Error, 'disabled',
-                                introspect.introspect, self.uuid,
-                                new_ipmi_credentials=self.new_creds)
+        self.assertRaisesRegex(utils.Error, 'disabled',
+                               introspect.introspect, self.uuid,
+                               new_ipmi_credentials=self.new_creds)
 
     def test_no_username(self, client_mock, add_mock, filters_mock):
         self._prepare(client_mock)
@@ -444,10 +471,10 @@ class TestAbort(BaseTest):
     def test_node_not_found(self, client_mock, get_mock, filters_mock):
         cli = self._prepare(client_mock)
         exc = utils.Error('Not found.', code=404)
-        get_mock.side_effect = iter([exc])
+        get_mock.side_effect = exc
 
-        self.assertRaisesRegexp(utils.Error, str(exc),
-                                introspect.abort, self.uuid)
+        self.assertRaisesRegex(utils.Error, str(exc),
+                               introspect.abort, self.uuid)
 
         self.assertEqual(0, filters_mock.call_count)
         self.assertEqual(0, cli.node.set_power_state.call_count)
@@ -459,8 +486,8 @@ class TestAbort(BaseTest):
         self.node_info.acquire_lock.return_value = False
         self.node_info.started_at = time.time()
 
-        self.assertRaisesRegexp(utils.Error, 'Node is locked, please, '
-                                'retry later', introspect.abort, self.uuid)
+        self.assertRaisesRegex(utils.Error, 'Node is locked, please, '
+                               'retry later', introspect.abort, self.uuid)
 
         self.assertEqual(0, filters_mock.call_count)
         self.assertEqual(0, cli.node.set_power_state.call_count)
@@ -487,7 +514,7 @@ class TestAbort(BaseTest):
         self.node_info.acquire_lock.return_value = True
         self.node_info.started_at = time.time()
         self.node_info.finished_at = None
-        filters_mock.side_effect = iter([Exception('Boom')])
+        filters_mock.side_effect = Exception('Boom')
 
         introspect.abort(self.uuid)
 
@@ -506,7 +533,7 @@ class TestAbort(BaseTest):
         self.node_info.acquire_lock.return_value = True
         self.node_info.started_at = time.time()
         self.node_info.finished_at = None
-        cli.node.set_power_state.side_effect = iter([Exception('BadaBoom')])
+        cli.node.set_power_state.side_effect = Exception('BadaBoom')
 
         introspect.abort(self.uuid)
 
